/*******************************************************************************
* File Name: LCD_DOE_PM.c
* Version 1.80
*
* Description:
*  This file contains the setup, control, and status commands to support 
*  the component operation in the low power mode. 
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "LCD_DOE.h"

/* Check for removal by optimization */
#if !defined(LCD_DOE_Sync_ctrl_reg__REMOVED)

static LCD_DOE_BACKUP_STRUCT  LCD_DOE_backup = {0u};

    
/*******************************************************************************
* Function Name: LCD_DOE_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void LCD_DOE_SaveConfig(void) 
{
    LCD_DOE_backup.controlState = LCD_DOE_Control;
}


/*******************************************************************************
* Function Name: LCD_DOE_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*
*******************************************************************************/
void LCD_DOE_RestoreConfig(void) 
{
     LCD_DOE_Control = LCD_DOE_backup.controlState;
}


/*******************************************************************************
* Function Name: LCD_DOE_Sleep
********************************************************************************
*
* Summary:
*  Prepares the component for entering the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void LCD_DOE_Sleep(void) 
{
    LCD_DOE_SaveConfig();
}


/*******************************************************************************
* Function Name: LCD_DOE_Wakeup
********************************************************************************
*
* Summary:
*  Restores the component after waking up from the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void LCD_DOE_Wakeup(void)  
{
    LCD_DOE_RestoreConfig();
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
