/*******************************************************************************
* File Name: LCD_D_PM.c
* Version 1.80
*
* Description:
*  This file contains the setup, control, and status commands to support 
*  the component operation in the low power mode. 
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "LCD_D.h"

/* Check for removal by optimization */
#if !defined(LCD_D_Sync_ctrl_reg__REMOVED)

static LCD_D_BACKUP_STRUCT  LCD_D_backup = {0u};

    
/*******************************************************************************
* Function Name: LCD_D_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void LCD_D_SaveConfig(void) 
{
    LCD_D_backup.controlState = LCD_D_Control;
}


/*******************************************************************************
* Function Name: LCD_D_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*
*******************************************************************************/
void LCD_D_RestoreConfig(void) 
{
     LCD_D_Control = LCD_D_backup.controlState;
}


/*******************************************************************************
* Function Name: LCD_D_Sleep
********************************************************************************
*
* Summary:
*  Prepares the component for entering the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void LCD_D_Sleep(void) 
{
    LCD_D_SaveConfig();
}


/*******************************************************************************
* Function Name: LCD_D_Wakeup
********************************************************************************
*
* Summary:
*  Restores the component after waking up from the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void LCD_D_Wakeup(void)  
{
    LCD_D_RestoreConfig();
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
