/*******************************************************************************
* File Name: LCD_Dout_PM.c
* Version 1.80
*
* Description:
*  This file contains the setup, control, and status commands to support 
*  the component operation in the low power mode. 
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "LCD_Dout.h"

/* Check for removal by optimization */
#if !defined(LCD_Dout_Sync_ctrl_reg__REMOVED)

static LCD_Dout_BACKUP_STRUCT  LCD_Dout_backup = {0u};

    
/*******************************************************************************
* Function Name: LCD_Dout_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void LCD_Dout_SaveConfig(void) 
{
    LCD_Dout_backup.controlState = LCD_Dout_Control;
}


/*******************************************************************************
* Function Name: LCD_Dout_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*
*******************************************************************************/
void LCD_Dout_RestoreConfig(void) 
{
     LCD_Dout_Control = LCD_Dout_backup.controlState;
}


/*******************************************************************************
* Function Name: LCD_Dout_Sleep
********************************************************************************
*
* Summary:
*  Prepares the component for entering the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void LCD_Dout_Sleep(void) 
{
    LCD_Dout_SaveConfig();
}


/*******************************************************************************
* Function Name: LCD_Dout_Wakeup
********************************************************************************
*
* Summary:
*  Restores the component after waking up from the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void LCD_Dout_Wakeup(void)  
{
    LCD_Dout_RestoreConfig();
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
