/*
	UL024TF (CGLCD Display) Subroutines
	Imprementation
*/
#include <stdio.h>
#include "UL024TF.h"

#define ILI9325_d_Write LCD_Dout_Write
#define ILI9325_d_Read LCD_Din_Read
#define ILI9325_doe_Write LCD_DOE_Write
#define ILI9325_doe_Read LCD_DOE_Read
#define ILI9325_nReset_Write LCD_nRST_Write
#define ILI9325_d_c_Write LCD_RS_Write
#define ILI9325_d_c_Read LCD_RS_Read
#define ILI9325_ncs_Write LCD_nCS_Write
#define ILI9325_ncs_Read LCD_nCS_Read
#define ILI9325_nrd_Write LCD_nRD_Write
#define ILI9325_nrd_Read LCD_nRD_Read
#define ILI9325_nwr_Write LCD_nWR_Write
#define ILI9325_nwr_Read LCD_nWR_Read

static void Reset_UL024TF() {
	ILI9325_nReset_Write(1);
	CyDelay(1); /* 1ms */
	ILI9325_nReset_Write(0);
	CyDelay(10); /* 10ms */
	ILI9325_nReset_Write(1);
	CyDelay(50); /* 50ms */
}

void ILI9325_Intf_Write8(uint8 f, uint8 x) {
	ILI9325_d_c_Write(f); // 0:command, 1:data
	ILI9325_d_Write(x); // write data to buffer
	ILI9325_doe_Write(1); // data output enable
	ILI9325_nwr_Write(0); // WR flag on
//	CyDelayUs(1); // 1 micro second waiting
	ILI9325_nwr_Write(1); // WR flag off
}

uint8 ILI9325_Intf_Read8(uint8 f) {
	uint8 x;
	ILI9325_d_c_Write(f); // 0:command, 1:data
	ILI9325_doe_Write(0); // data output disable (read enable)
	ILI9325_nrd_Write(0); // RD flag on
//	CyDelayUs(1); // 1 micro second waiting
	x = ILI9325_d_Read();
	ILI9325_nrd_Write(1); // RD flag off
	return x;
}

static void ILI9325_Write(uint8 f, uint16 r) {
	ILI9325_Intf_Write8(f, (uint8)(r >> 8));
	ILI9325_Intf_Write8(f, (uint8)(r & 0xff));
}

void ILI9325_CtrlWrite(uint16 r, uint16 v) {
	ILI9325_Intf_Write8(0, (uint8)(r >> 8));
	ILI9325_Intf_Write8(0, (uint8)(r & 0xff));
	ILI9325_Intf_Write8(1, (uint8)(v >> 8));
	ILI9325_Intf_Write8(1, (uint8)(v & 0xff));  
}

uint16 ILI9325_CtrlRead(uint16 r) {
	uint16 vl, vh;
	ILI9325_Intf_Write8(0, (uint8)(r >> 8));
	ILI9325_Intf_Write8(0, (uint8)(r & 0xff));
	vh = ILI9325_Intf_Read8(1);
	vl = ILI9325_Intf_Read8(1);
	return (vh << 8) + vl;
}

#define delayms CyDelay
static void ILI9325_Initialize(void) {
  // ILI9325 CPT 2.4Inch Initinal Code from Application Note Ver0.25
  //************* Start Initial Sequence **********//
  ILI9325_CtrlWrite(0x00E3, 0x3008); // Set internal timing
  ILI9325_CtrlWrite(0x00E7, 0x0012); // Set internal timing
  ILI9325_CtrlWrite(0x00EF, 0x1231); // Set internal timing
  ILI9325_CtrlWrite(0x0001, 0x0100); // set SS and SM bit
  ILI9325_CtrlWrite(0x0002, 0x0700); // set 1 line inversion
  ILI9325_CtrlWrite(0x0003, 0x1030); // set GRAM write direction and BGR=1.
  ILI9325_CtrlWrite(0x0004, 0x0000); // Resize register
  ILI9325_CtrlWrite(0x0008, 0x0207); // set the back porch and front porch
  ILI9325_CtrlWrite(0x0009, 0x0000); // set non-display area refresh cycle ISC[3:0]
  ILI9325_CtrlWrite(0x000A, 0x0000); // FMARK function
  ILI9325_CtrlWrite(0x000C, 0x0000); // RGB interface setting
  ILI9325_CtrlWrite(0x000D, 0x0000); // Frame marker Position
  ILI9325_CtrlWrite(0x000F, 0x0000); // RGB interface polarity
  //*************Power On sequence ****************//
  ILI9325_CtrlWrite(0x0010, 0x0000); // SAP, BT[3:0], AP, DSTB, SLP, STB
  ILI9325_CtrlWrite(0x0011, 0x0007); // DC1[2:0], DC0[2:0], VC[2:0]
  ILI9325_CtrlWrite(0x0012, 0x0000); // VREG1OUT voltage
  ILI9325_CtrlWrite(0x0013, 0x0000); // VDV[4:0] for VCOM amplitude
    delayms(200);                        // Dis-charge capacitor power voltage
  ILI9325_CtrlWrite(0x0010, 0x1490); // SAP, BT[3:0], AP, DSTB, SLP, STB
  ILI9325_CtrlWrite(0x0011, 0x0227); // R11h=0x0221 at VCI=3.3V, DC1[2:0], DC0[2:0], VC[2:0]
    delayms(50);                         // Delay 50ms
  ILI9325_CtrlWrite(0x0012, 0x001C); // Internal reference voltage= Vci;
    delayms(50);                         // Delay 50ms
  ILI9325_CtrlWrite(0x0013, 0x1A00); // Set VDV[4:0] for VCOM amplitude
  ILI9325_CtrlWrite(0x0029, 0x0025); // Set VCM[5:0] for VCOMH
  ILI9325_CtrlWrite(0x002B, 0x000C); // Set Frame Rate
    delayms(50);                         // Delay 50ms
  ILI9325_CtrlWrite(0x0020, 0x0000); // GRAM horizontal Address
  ILI9325_CtrlWrite(0x0021, 0x0000); // GRAM Vertical Address
  // ----------- Adjust the Gamma Curve ----------//
  ILI9325_CtrlWrite(0x0030, 0x0000);
  ILI9325_CtrlWrite(0x0031, 0x0506);
  ILI9325_CtrlWrite(0x0032, 0x0104);
  ILI9325_CtrlWrite(0x0035, 0x0207);
  ILI9325_CtrlWrite(0x0036, 0x000F);
  ILI9325_CtrlWrite(0x0037, 0x0306);
  ILI9325_CtrlWrite(0x0038, 0x0102);
  ILI9325_CtrlWrite(0x0039, 0x0707);
  ILI9325_CtrlWrite(0x003C, 0x0702);
  ILI9325_CtrlWrite(0x003D, 0x1604);
  //------------------ Set GRAM area ---------------//
  ILI9325_CtrlWrite(0x0050, 0x0000); // Horizontal GRAM Start Address
  ILI9325_CtrlWrite(0x0051, 0x00EF); // Horizontal GRAM End Address
  ILI9325_CtrlWrite(0x0052, 0x0000); // Vertical GRAM Start Address
  ILI9325_CtrlWrite(0x0053, 0x013F); // Vertical GRAM Start Address
  ILI9325_CtrlWrite(0x0060, 0xA700); // Gate Scan Line
  ILI9325_CtrlWrite(0x0061, 0x0001); // NDL,VLE, REV
  ILI9325_CtrlWrite(0x006A, 0x0000); // set scrolling line
  //-------------- Partial Display Control ---------//
  ILI9325_CtrlWrite(0x0080, 0x0000);
  ILI9325_CtrlWrite(0x0081, 0x0000);
  ILI9325_CtrlWrite(0x0082, 0x0000);
  ILI9325_CtrlWrite(0x0083, 0x0000);
  ILI9325_CtrlWrite(0x0084, 0x0000);
  ILI9325_CtrlWrite(0x0085, 0x0000);
  //-------------- Panel Control -------------------//
  ILI9325_CtrlWrite(0x0090, 0x0010);
  ILI9325_CtrlWrite(0x0092, 0x0600);
  ILI9325_CtrlWrite(0x0007, 0x0133); // 262K color and display ON
}

void UL024TF_Initialize() {
	Reset_UL024TF();
	ILI9325_ncs_Write(0); // chip select enable	
    ILI9325_Initialize();
}

uint16 UL024TF_SetColor(uint8 r, uint8 g, uint8 b) {
  return (((r >> 3) & 0x1f) << 11) + (((g >> 2) & 0x3f) << 5) + ((b >> 3) & 0x1f);
}

void UL024TF_GetColor(uint16 c, uint8 *r, uint8 *g, uint8 *b) {
  *r = ((c >> 11) & 0x1f) << 3;
  *g = ((c >> 5) & 0x3f) << 2;
  *b = (c & 0x1f) << 3;
}

static void UL024TF_SendAreaInfo(uint16 x, uint16 y, uint16 w, uint16 h) {
	ILI9325_CtrlWrite(0x0050, UL024TF_H-(y+h)); // ymin
	ILI9325_CtrlWrite(0x0051, UL024TF_H-(y+1)); // ymax
	ILI9325_CtrlWrite(0x0052, x); // xmin
	ILI9325_CtrlWrite(0x0053, x+w-1); // xmax
	ILI9325_CtrlWrite(0x0020, UL024TF_H-(y+h)); // ystart
	ILI9325_CtrlWrite(0x0021, x); // xstart
}

void UL024TF_PaintBox(uint16 x, uint16 y, uint16 w, uint16 h, uint16 c) {
	uint16 i, j;
	UL024TF_SendAreaInfo(x, y, w, h);
	ILI9325_Write(0, 0x0022); // Write VRAM & Increment
	for (i = 0; i < w; i++) 
		for (j = 0; j < h; j++)
			ILI9325_Write(1, c);
}

void UL024TF_SetImage(uint16 x, uint16 y, uint16 w, uint16 h, uint16 *img) {
	uint16 i, j;
	UL024TF_SendAreaInfo(x, y, w, h);
	ILI9325_Write(0, 0x0022); // Write VRAM & Increment
	for (i = 0; i < w; i++) 
		for (j = 0; j < h; j++)
//			ILI9325_Write(1, img[UL024TF_H-(y+h-j)*UL024TF_W+i]);
			ILI9325_Write(1, img[j * w + i]);
}

/* [] END OF FILE */
